stream : Real-time Whisper transcription in WebAssembly
You can find more about this project on GitHub.

Select the model you would like to use, click the "Start" button and start speaking
Whisper model:
Status: not started

    [The transcribed text will be displayed here]

Debug output:
Troubleshooting
The page does some heavy computations, so make sure:

- To use a modern web browser (e.g. Chrome, Firefox)
- To use a fast desktop or laptop computer (i.e. not a mobile phone)
- Your browser supports WASM Fixed-width SIMD

| Build time: @GIT_DATE@ | Commit hash: @GIT_SHA1@ | Commit subject: @GIT_COMMIT_SUBJECT@ | Source Code |